aboutsummaryrefslogtreecommitdiffstats
path: root/resources/libraries/python/VPPUtil.py
diff options
context:
space:
mode:
Diffstat (limited to 'resources/libraries/python/VPPUtil.py')
-rw-r--r--resources/libraries/python/VPPUtil.py14
1 files changed, 7 insertions, 7 deletions
diff --git a/resources/libraries/python/VPPUtil.py b/resources/libraries/python/VPPUtil.py
index f6b3afae28..9d2a2b9dd3 100644
--- a/resources/libraries/python/VPPUtil.py
+++ b/resources/libraries/python/VPPUtil.py
@@ -213,26 +213,26 @@ class VPPUtil(object):
VPPUtil.vpp_enable_traces_on_dut(node)
@staticmethod
- def vpp_enable_barrier_traces_on_dut(node):
- """Enable vpp barrier traces on the DUT node.
+ def vpp_enable_elog_traces_on_dut(node):
+ """Enable API/CLI/Barrier traces on the DUT node.
:param node: DUT node to set up.
:type node: dict
"""
vat = VatExecutor()
- vat.execute_script("test_threads_barrier_elog.vat", node,
+ vat.execute_script("elog_trace_api_cli_barrier.vat", node,
json_out=False)
@staticmethod
- def vpp_enable_barrier_traces_on_all_duts(nodes):
- """Enable vpp barrier traces on all DUTs in the given topology.
+ def vpp_enable_elog_traces_on_all_duts(nodes):
+ """Enable API/CLI/Barrier traces on all DUTs in the given topology.
:param nodes: Nodes in the topology.
:type nodes: dict
"""
for node in nodes.values():
if node['type'] == NodeType.DUT:
- VPPUtil.vpp_enable_barrier_traces_on_dut(node)
+ VPPUtil.vpp_enable_elog_traces_on_dut(node)
@staticmethod
def show_event_logger_on_dut(node):
@@ -253,4 +253,4 @@ class VPPUtil(object):
"""
for node in nodes.values():
if node['type'] == NodeType.DUT:
- VPPUtil.show_event_logger_on_dut(node) \ No newline at end of file
+ VPPUtil.show_event_logger_on_dut(node)